@@ -19,18 +19,43 @@ import shutil
 import sys
 
 # Third party imports
-from qtpy import PYQT5
+from qtpy import PYQT5, PYQT6
 from qtpy.compat import getexistingdirectory, getsavefilename
-from qtpy.QtCore import QDir, QMimeData, Qt, QTimer, QUrl, Signal, Slot
+from qtpy.QtCore import (
+    QDir,
+    QMimeData,
+    QSortFilterProxyModel,
+    Qt,
+    QTimer,
+    QUrl,
+    Signal,
+    Slot,
+)
 from qtpy.QtGui import QDrag
-from qtpy.QtWidgets import (QApplication, QDialog, QDialogButtonBox,
-                            QFileSystemModel, QInputDialog, QLabel, QLineEdit,
-                            QMessageBox, QProxyStyle, QStyle, QTextEdit,
-                            QToolTip, QTreeView, QVBoxLayout)
+from qtpy.QtWidgets import (
+    QAbstractItemView,
+    QApplication,
+    QDialog,
+    QDialogButtonBox,
+    QFileSystemModel,
+    QInputDialog,
+    QLabel,
+    QLineEdit,
+    QMessageBox,
+    QProxyStyle,
+    QStyle,
+    QStyledItemDelegate,
+    QStyleOptionViewItem,
+    QTextEdit,
+    QToolTip,
+    QTreeView,
+    QVBoxLayout,
+)
 
 # Local imports
 from spyder.api.config.decorators import on_conf_change
 from spyder.api.translations import _
+from spyder.api.widgets.dialogs import SpyderDialogButtonBox
 from spyder.api.widgets.mixins import SpyderWidgetMixin
 from spyder.config.base import get_home_dir
 from spyder.config.main import NAME_FILTERS
@@ -149,6 +174,48 @@ class DirViewStyle(QProxyStyle):
         return super().styleHint(hint, option, widget, return_data)
 
 
+class DirViewItemDelegate(QStyledItemDelegate):
+
+    def __init__(self, parent):
+        super().__init__(parent)
+        self._project_dir = ""
+
+    def set_project_dir(self, project_dir):
+        self._project_dir = project_dir
+
+    def initStyleOption(self, option, index):
+        """
+        To change the item icon when expanding a folder.
+
+        From https://stackoverflow.com/a/48531349/438386
+        """
+        super().initStyleOption(option, index)
+
+        if isinstance(option, QStyleOptionViewItem):
+            model = index.model()
+
+            if isinstance(model, QSortFilterProxyModel):
+                # This is necessary for Projects because it has a proxy model
+                is_dir = model.sourceModel().isDir(model.mapToSource(index))
+            else:
+                is_dir = model.isDir(index)
+
+            if is_dir:
+                # This is necessary because Projects has a root directory and
+                # we want to set a different icon for it.
+                if isinstance(model, QSortFilterProxyModel):
+                    dir_path = model.sourceModel().filePath(
+                        model.mapToSource(index)
+                    )
+                else:
+                    dir_path = None
+
+                if dir_path == self._project_dir:
+                    option.icon = ima.icon("project_spyder")
+                elif (option.state & QStyle.State_Open):
+                    option.icon = ima.icon("DirOpenIcon")
+
+
 # ---- Widgets
 # ----------------------------------------------------------------------------
 class DirView(QTreeView, SpyderWidgetMixin):
@@ -267,7 +334,7 @@ class DirView(QTreeView, SpyderWidgetMixin):
         parent: QWidget
             Parent QWidget of the widget.
         """
-        if PYQT5:
+        if PYQT5 or PYQT6:
             super().__init__(parent=parent, class_parent=parent)
         else:
             QTreeView.__init__(self, parent)
@@ -297,10 +364,13 @@ class DirView(QTreeView, SpyderWidgetMixin):
         self._style = DirViewStyle(None)
         self._style.setParent(self)
         self.setStyle(self._style)
+        self.setItemDelegate(DirViewItemDelegate(self))
 
         # Setup
         self.setup_fs_model()
-        self.setSelectionMode(self.ExtendedSelection)
+        self.setSelectionMode(
+            QAbstractItemView.SelectionMode.ExtendedSelection
+        )
         header.setContextMenuPolicy(Qt.CustomContextMenu)
 
         # Track mouse movements. This activates the mouseMoveEvent declared
@@ -336,7 +406,7 @@ class DirView(QTreeView, SpyderWidgetMixin):
 
         new_package_action = self.create_action(
             DirViewActions.NewPackage,
-            text=_("Python Package..."),
+            text=_("Python package..."),
             icon=self.create_icon('package_new'),
             triggered=self.new_package,
         )
@@ -403,14 +473,14 @@ class DirView(QTreeView, SpyderWidgetMixin):
 
         self.copy_absolute_path_action = self.create_action(
             DirViewActions.CopyAbsolutePath,
-            text=_("Copy Absolute Path"),
+            text=_("Copy absolute path"),
             triggered=self.copy_absolute_path,
             register_shortcut=True,
         )
 
         self.copy_relative_path_action = self.create_action(
             DirViewActions.CopyRelativePath,
-            text=_("Copy Relative Path"),
+            text=_("Copy relative path"),
             triggered=self.copy_relative_path,
             register_shortcut=True
         )
@@ -419,7 +489,7 @@ class DirView(QTreeView, SpyderWidgetMixin):
         if sys.platform == 'darwin':
             show_in_finder_text = _("Show in Finder")
         else:
-            show_in_finder_text = _("Show in Folder")
+            show_in_finder_text = _("Show in folder")
 
         show_in_system_explorer_action = self.create_action(
             DirViewActions.ShowInSystemExplorer,
@@ -430,13 +500,16 @@ class DirView(QTreeView, SpyderWidgetMixin):
         # Version control actions
         self.vcs_commit_action = self.create_action(
             DirViewActions.VersionControlCommit,
-            text=_("Commit"),
+            # Don't translate this text because it makes little sense in
+            # languages other than English.
+            # Fixes spyder-ide/spyder#21959
+            text="Git commit",
             icon=self.create_icon('vcs_commit'),
             triggered=lambda: self.vcs_command('commit'),
         )
         self.vcs_log_action = self.create_action(
             DirViewActions.VersionControlBrowse,
-            text=_("Browse repository"),
+            text=_("Browse Git repository"),
             icon=self.create_icon('vcs_browse'),
             triggered=lambda: self.vcs_command('browse'),
         )
@@ -865,7 +938,12 @@ class DirView(QTreeView, SpyderWidgetMixin):
     def startDrag(self, dropActions):
         """Reimplement Qt Method - handle drag event"""
         data = QMimeData()
-        data.setUrls([QUrl(fname) for fname in self.get_selected_filenames()])
+        data.setUrls(
+            [
+                QUrl.fromLocalFile(fname)
+                for fname in self.get_selected_filenames()
+            ]
+        )
         drag = QDrag(self)
         drag.setMimeData(data)
         drag.exec_()
@@ -1007,9 +1085,11 @@ class DirView(QTreeView, SpyderWidgetMixin):
             filters.setPlainText(", ".join(self.get_conf('name_filters')))
 
         # Dialog buttons
-        button_box = QDialogButtonBox(QDialogButtonBox.Reset |
-                                      QDialogButtonBox.Ok |
-                                      QDialogButtonBox.Cancel)
+        button_box = SpyderDialogButtonBox(
+            QDialogButtonBox.Reset
+            | QDialogButtonBox.Ok
+            | QDialogButtonBox.Cancel
+        )
         button_box.accepted.connect(handle_ok)
         button_box.rejected.connect(dialog.reject)
         button_box.button(QDialogButtonBox.Reset).clicked.connect(handle_reset)
@@ -1682,7 +1762,7 @@ class DirView(QTreeView, SpyderWidgetMixin):
     def reset_icon_provider(self):
         """Reset file system model icon provider
         The purpose of this is to refresh files/directories icons"""
-        self.fsmodel.setIconProvider(IconProvider(self))
+        self.fsmodel.setIconProvider(IconProvider())
 
     def convert_notebook(self, fname):
         """Convert an IPython notebook to a Python script in editor"""
